@@ -15,7 +15,8 @@ def get_session(database_uri: str) -> Generator:
     global _session_local
     _engine = _engine or create_engine(database_uri, pool_pre_ping=True)
     _session_local = _session_local or sessionmaker(
-        autocommit=False, autoflush=False, bind=_engine)
+        autocommit=False, autoflush=False, bind=_engine
+    )
     try:
         session_instance = _session_local()
         yield session_instance
