@@ -7,14 +7,9 @@ import google.cloud.logging
 
 
 def setup_logging(level=logging.INFO):  # pragma: no coverage
-    """ Setup logging
-    """
+    """Setup logging"""
     client = google.cloud.logging.Client()
-    excluded_logger_defaults = (
-        "google.cloud",
-        "google.auth",
-        "google_auth_httplib2"
-    )
+    excluded_logger_defaults = ("google.cloud", "google.auth", "google_auth_httplib2")
 
     # don't propagate excluded loggers (and don't send them to stderr either)
     for logger_name in excluded_logger_defaults:
